@@ -15,9 +15,9 @@ class LIB:
     @staticmethod
     def token_get(word: str) -> str:
         key = Fernet.generate_key()
-        f = Fernet(key)
-        token = f.encrypt(word.encode())
-        return token.decode()
+        #f = Fernet(key)
+        #token = f.encrypt(word.encode())
+        return key
 
     @staticmethod
     def findchar(string: str, substring: str, ocorrencia: int, inicio: int = 0, fim: int = None):
